==> igniteui-angular-charts-13.2.0-beta.0.tgz: package/esm5/lib/DataToolTipLayerFrame.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Frame } from "./Frame";
import { List$1 } from "igniteui-angular-core";
import { Base, Number_$type, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
import { FrameExtended } from "./FrameExtended";
import { InterpolationUtil } from "igniteui-angular-core";
/**
 * @hidden
 */
var DataToolTipLayerFrame = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataToolTipLayerFrame, _super);
    function DataToolTipLayerFrame() {
        var _this = _super.call(this) || this;
        _this.m = null;
        _this.l = null;
        _this.g = null;
        _this.f = null;
        _this.i = null;
        _this.k = null;
        _this.j = null;
        _this.h = null;
        _this.m = new List$1(Number_$type, 0);
        _this.l = new List$1(Number_$type, 0);
        _this.g = new List$1(Number_$type, 0);
        _this.f = new List$1(Number_$type, 0);
        _this.i = new List$1(Base.$, 0);
        _this.k = new List$1(Number_$type, 0);
        _this.j = new List$1(Number_$type, 0);
        _this.h = new List$1(Brush.$, 0);
        return _this;
    }
    DataToolTipLayerFrame.prototype.c = function (a, b, c) {
        var d = b;
        var e = c;
        Frame.b(this.m, a, d.o, e.o);
        Frame.b(this.l, a, d.n, e.n);
        Frame.b(this.g, a, d.g, e.g);
        Frame.b(this.f, a, d.f, e.f);
        Frame.b(this.k, a, d.m, e.m);
        Frame.b(this.j, a, d.k, e.k);
        FrameExtended.a(this.h, a, d.h, e.h, 0);
        InterpolationUtil.c(Base.$, this.i, a, d.i, e.i, function () { return null; }, function (f, g, h, i) { return i; });
    };
    DataToolTipLayerFrame.$t = markType(DataToolTipLayerFrame, 'DataToolTipLayerFrame', Frame.$);
    return DataToolTipLayerFrame;
}(Frame));
export { DataToolTipLayerFrame };

==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/DataToolTipLayerFrame.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Frame } from "./Frame";
import { List$1 } from "igniteui-angular-core";
import { Base, Number_$type, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
import { FrameExtended } from "./FrameExtended";
import { InterpolationUtil } from "igniteui-angular-core";
/**
 * @hidden
 */
var DataToolTipLayerFrame = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataToolTipLayerFrame, _super);
    function DataToolTipLayerFrame() {
        var _this = _super.call(this) || this;
        _this.m = null;
        _this.l = null;
        _this.g = null;
        _this.f = null;
        _this.i = null;
        _this.k = null;
        _this.j = null;
        _this.h = null;
        _this.m = new List$1(Number_$type, 0);
        _this.l = new List$1(Number_$type, 0);
        _this.g = new List$1(Number_$type, 0);
        _this.f = new List$1(Number_$type, 0);
        _this.i = new List$1(Base.$, 0);
        _this.k = new List$1(Number_$type, 0);
        _this.j = new List$1(Number_$type, 0);
        _this.h = new List$1(Brush.$, 0);
        return _this;
    }
    DataToolTipLayerFrame.prototype.c = function (a, b, c) {
        var d = b;
        var e = c;
        Frame.b(this.m, a, d.m, e.m);
        Frame.b(this.l, a, d.l, e.l);
        Frame.b(this.g, a, d.g, e.g);
        Frame.b(this.f, a, d.f, e.f);
        Frame.b(this.k, a, d.k, e.k);
        Frame.b(this.j, a, d.j, e.j);
        FrameExtended.a(this.h, a, d.h, e.h, 0);
        InterpolationUtil.c(Base.$, this.i, a, d.i, e.i, function () { return null; }, function (f, g, h, i) { return i; });
    };
    DataToolTipLayerFrame.$t = markType(DataToolTipLayerFrame, 'DataToolTipLayerFrame', Frame.$);
    return DataToolTipLayerFrame;
}(Frame));
export { DataToolTipLayerFrame };
